==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/bg_BG.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Документи",
"Can't create document" => "Неуспешно създаване на документ",
"You don't have permission to rename this document" => "Нямате права да преименувате този документ",
"Directory saved successfully." => "Директорията е успешно запазена.",
"An error occurred while changing directory." => "Настъпи грешка при смяната на директорията.",
"Saved" => "Запазване",
"Format filter server is down or misconfigured" => "Сървърът за филтриране на форматите не работи или не е правилно настроен.",
"Conversion failed. Check log for details." => "Преобразуването е неуспешно. Проверете доклада за повече подробности.",
"Saving..." => "Запазване...",
"Failed to load documents." => "Неуспешно зареждане на документите.",
"No documents were found. Upload or create a document to get started!" => "Не са открити документи. Качете или създайте документ, за да започнете!",
"No connection to server. Trying to reconnect." => "Няма връзка със сървъра. Опитване за повторно свързване.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Напускането на режим Редактиране може да доведе до загуба на незапазена информация. Вместо това се препоръчва използването на бутона 'Затваряне'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Зареждането на този документ е неуспешно. Моля, проверете дали може да бъде отворен с външен редактор за odt. Това може да означава, че е споделянето му е отменено или е бил изтрит наскоро.",
"Save" => "Запазване",
"Loading documents..." => "Зареждане на документите...",
"'.' is an invalid file name." => "'.' е невалидно име за файл.",
"File name cannot be empty." => "Името на файла не може да бъде празно.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Невалидно име, '\\', '/', '<', '>', ':', '\"', '|', '?' и '*' не са разрешени.",
"Align Left" => "Ляво подравняване",
"Alignment" => "Подравняване",
"Align Right" => "Дясно подравняване",
"Annotate" => "Анотация",
"Background" => "Фон",
"Bold" => "Удебелен",
"Bottom" => "Долу",
"Cancel" => "Отказ",
"Center" => "Центриран",
"Clone" => "Клониране",
"Clone this Style" => "Клониране на стила",
"Close" => "Затваряне",
"Color" => "Цвят",
"Create" => "Създаване",
"Decrease Indent" => "Намаляване на отстъпването",
"Default Style" => "Стил по подразбиране",
"Delete" => "Изтриване",
"Family" => "Семейство",
"Font" => "Шрифт",
"Font Effects" => "Ефекти на шрифта",
"Format" => "Форматиране",
"Increase Indent" => "Увеличаване на отстъпването",
"Insert Image" => "Вмъкване на изображение",
"Invite Members" => "Покана на членове",
"Italic" => "Курсивен",
"Justified" => "Разширен",
"Justify" => "Разшири",
"Left" => "Ляво",
"Loading" => "Зареждане",
"Members" => "Членове",
"New Name:" => "Ново Име:",
"OK" => "ОК",
"Open" => "Отвори",
"Options" => "Настройки",
"Paragraph..." => "Параграф...",
"Paragraph Styles" => "Стил на Параграфа",
"Redo" => "Повтори",
"Right" => "Дясно",
"Size" => "Размер",
"Spacing" => "Разстояние между буквите",
"Strikethrough" => "Зачертано",
"Style" => "Стил",
"Text" => "Текст",
"Top" => "Горе",
"Underline" => "Подчертано",
"Undo" => "Върни",
"Unknown Author" => "Непознат Автор",
"Edit" => "Промени",
"Share" => "Сподели",
"guest" => "гост",
"MS Word support (requires openOffice/libreOffice)" => "Подръжка на MS Word (изисква openOffice/libreOffice)",
"Local" => "Локален",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice е инсталиран на този сървър. Пътя до изпълнимия файл е зададен чрез preview_libreoffice_path в config.php",
"External" => "Външен",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice е инсталиран на външен съвър, на който работи сървър за филтриране на форматите.",
"Disabled" => "Изключено",
"No MS Word support" => "Не поддържа MS Word",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Адрес на Сървъра",
"Apply and test" => "Приложи и тествай",
"New document" => "Нов документ",
"Upload (max. %s)" => "Качване (макс. %s)",
"Upload" => "Качи",
"Save new documents to" => "Запази новите документи в",
"Wrong password. Please retry." => "Грешна парола. Опитай пак.",
"Password" => "Парола",
"Guest %s" => "Гост %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Този линк е изтекъл или никога не е съществувал. Моля, свържи се с човекът, който го е споделил с теб.",
"Advanced feature-set" => "Допълнителни функции",
"(Unstable)" => "(Нестабилно)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/bg_BG.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Документи",
"Can't create document" => "Неуспешно създаване на документ",
"You don't have permission to rename this document" => "Нямате права да преименувате този документ",
"Directory saved successfully." => "Директорията е успешно запазена.",
"An error occurred while changing directory." => "Настъпи грешка при смяната на директорията.",
"Saved" => "Запазване",
"Format filter server is down or misconfigured" => "Сървърът за филтриране на форматите не работи или не е правилно настроен.",
"Conversion failed. Check log for details." => "Преобразуването е неуспешно. Проверете доклада за повече подробности.",
"Saving..." => "Запазване...",
"Failed to load documents." => "Неуспешно зареждане на документите.",
"No documents were found. Upload or create a document to get started!" => "Не са открити документи. Качете или създайте документ, за да започнете!",
"No connection to server. Trying to reconnect." => "Няма връзка със сървъра. Опитване за повторно свързване.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Напускането на режим Редактиране може да доведе до загуба на незапазена информация. Вместо това се препоръчва използването на бутона 'Затваряне'.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Зареждането на този документ е неуспешно. Моля, проверете дали може да бъде отворен с външен редактор за odt. Това може да означава, че е споделянето му е отменено или е бил изтрит наскоро.",
"Save" => "Запазване",
"Loading documents..." => "Зареждане на документите...",
"'.' is an invalid file name." => "'.' е невалидно име за файл.",
"File name cannot be empty." => "Името на файла не може да бъде празно.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Невалидно име, '\\', '/', '<', '>', ':', '\"', '|', '?' и '*' не са разрешени.",
"Align Left" => "Ляво подравняване",
"Alignment" => "Подравняване",
"Align Right" => "Дясно подравняване",
"Annotate" => "Анотация",
"Background" => "Фон",
"Bold" => "Удебелен",
"Bottom" => "Долу",
"Cancel" => "Отказ",
"Center" => "Центриран",
"Clone" => "Клониране",
"Clone this Style" => "Клониране на стила",
"Close" => "Затваряне",
"Color" => "Цвят",
"Create" => "Създаване",
"Decrease Indent" => "Намаляване на отстъпването",
"Default Style" => "Стил по подразбиране",
"Delete" => "Изтриване",
"Family" => "Семейство",
"Font" => "Шрифт",
"Font Effects" => "Ефекти на шрифта",
"Format" => "Форматиране",
"Increase Indent" => "Увеличаване на отстъпването",
"Insert Image" => "Вмъкване на изображение",
"Invite Members" => "Покана на членове",
"Italic" => "Курсивен",
"Justified" => "Разширен",
"Justify" => "Разшири",
"Left" => "Ляво",
"Loading" => "Зареждане",
"Members" => "Членове",
"New Name:" => "Ново Име:",
"OK" => "ОК",
"Open" => "Отвори",
"Options" => "Настройки",
"Paragraph..." => "Параграф...",
"Paragraph Styles" => "Стил на Параграфа",
"Redo" => "Повтори",
"Right" => "Дясно",
"Size" => "Размер",
"Spacing" => "Разстояние между буквите",
"Strikethrough" => "Зачертано",
"Style" => "Стил",
"Text" => "Текст",
"Top" => "Горе",
"Underline" => "Подчертано",
"Undo" => "Върни",
"Unknown Author" => "Непознат Автор",
"Shared" => "Споделено",
"Error" => "Грешка",
"Error while sharing" => "Грешка при споделяне",
"Error while unsharing" => "Грешка при премахване на споделянето",
"Error while changing permissions" => "Грешка при промяна на привилегиите",
"Shared with you and the group {group} by {owner}" => "Споделено от {owner} с Вас и групата {group} .",
"Shared with you by {owner}" => "Споделено с Вас от {owner}.",
"Share" => "Сподели",
"Share link" => "Връзка за споделяне",
"The public link will expire no later than {days} days after it is created" => "Общодостъпната връзка ще изтече не по-късно от {days} дни след създаването ѝ.",
"Link" => "Връзка",
"Password protect" => "Защитено с парола",
"Password" => "Парола",
"Choose a password for the public link" => "Изберете парола за общодостъпната връзка",
"Allow editing" => "Позволяване на редактиране",
"Email link to person" => "Имейл връзка към човек",
"Send" => "Изпращане",
"Set expiration date" => "Задаване на дата на изтичане",
"Expiration" => "Изтичане",
"Expiration date" => "Дата на изтичане",
"Adding user..." => "Добавяне на потребител...",
"group" => "група",
"remote" => "отдалечен",
"Resharing is not allowed" => "Повторно споделяне не е разрешено.",
"Shared in {item} with {user}" => "Споделено в {item} с {user}.",
"Unshare" => "Премахване на споделяне",
"notify by email" => "уведомяване по електронна поща",
"can share" => "може да споделя",
"can edit" => "може да променя",
"access control" => "контрол на достъпа",
"create" => "създаване",
"change" => "промяна",
"delete" => "изтриване",
"Password protected" => "Защитено с парола",
"Error unsetting expiration date" => "Грешка при премахване на дата на изтичане",
"Error setting expiration date" => "Грешка при настройване на датата за изтичане",
"Sending ..." => "Изпращане ...",
"Email sent" => "Електронната поща е изпратена",
"Warning" => "Предупреждение",
"Edit" => "Промени",
"guest" => "гост",
"MS Word support (requires openOffice/libreOffice)" => "Подръжка на MS Word (изисква openOffice/libreOffice)",
"Local" => "Локален",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice е инсталиран на този сървър. Пътя до изпълнимия файл е зададен чрез preview_libreoffice_path в config.php",
"External" => "Външен",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice е инсталиран на външен съвър, на който работи сървър за филтриране на форматите.",
"Disabled" => "Изключено",
"No MS Word support" => "Не поддържа MS Word",
"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
"Server URL" => "Адрес на Сървъра",
"Apply and test" => "Приложи и тествай",
"New document" => "Нов документ",
"Upload (max. %s)" => "Качване (макс. %s)",
"Upload" => "Качи",
"Save new documents to" => "Запази новите документи в",
"Wrong password. Please retry." => "Грешна парола. Опитай пак.",
"Guest %s" => "Гост %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Този линк е изтекъл или никога не е съществувал. Моля, свържи се с човекът, който го е споделил с теб.",
"Advanced feature-set" => "Допълнителни функции",
"(Unstable)" => "(Нестабилно)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
